/**
 * @file
 * VuoList_VuoCurve C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoCurve_H
#define VuoList_VuoCurve_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoCurve VuoList_VuoCurve
 * A list of @ref VuoCurve elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoCurve
 * A list of @ref VuoCurve elements.
 */
#ifndef VuoList_VuoCurve_TYPE_DEFINED
typedef void * VuoList_VuoCurve;
#endif

/**
 * Creates a new list of @ref VuoCurve elements.
 */
VuoList_VuoCurve VuoListCreate_VuoCurve(void);

/**
 * Returns the @ref VuoCurve at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoCurve VuoListGetValueAtIndex_VuoCurve(const VuoList_VuoCurve list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoCurve(VuoList_VuoCurve list, const VuoCurve value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoCurve(VuoList_VuoCurve list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoCurve(VuoList_VuoCurve list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoCurve(const VuoList_VuoCurve list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoCurve VuoList_VuoCurve_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoCurve_jsonFromValue(const VuoList_VuoCurve value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoCurve_summaryFromValue(const VuoList_VuoCurve value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoCurve VuoList_VuoCurve_valueFromString(const char *str);
char * VuoList_VuoCurve_stringFromValue(const VuoList_VuoCurve value);
/// @}

/**
 * @}
 */

#endif
