/**
 * @file
 * VuoList_VuoWave C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoWave_H
#define VuoList_VuoWave_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoWave VuoList_VuoWave
 * A list of @ref VuoWave elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoWave
 * A list of @ref VuoWave elements.
 */
#ifndef VuoList_VuoWave_TYPE_DEFINED
typedef void * VuoList_VuoWave;
#endif

/**
 * Creates a new list of @ref VuoWave elements.
 */
VuoList_VuoWave VuoListCreate_VuoWave(void);

/**
 * Returns the @ref VuoWave at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoWave VuoListGetValueAtIndex_VuoWave(const VuoList_VuoWave list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoWave(VuoList_VuoWave list, const VuoWave value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoWave(VuoList_VuoWave list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoWave(VuoList_VuoWave list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoWave(const VuoList_VuoWave list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoWave VuoList_VuoWave_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoWave_jsonFromValue(const VuoList_VuoWave value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoWave_summaryFromValue(const VuoList_VuoWave value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoWave VuoList_VuoWave_valueFromString(const char *str);
char * VuoList_VuoWave_stringFromValue(const VuoList_VuoWave value);
/// @}

/**
 * @}
 */

#endif
